import numpy as np
import scipy.io as sc
import matplotlib.pyplot as plt

from retrieval import instruments as ucats
import cats.uCATS_platform as sat
import sasktranif.sasktranif as skif
import radtran.sasktran as radtran
import radtran.atmosphere as atmosphere

num_exposures = 2
num_sensors = 7

wl   = [0,]*num_sensors

wl[0] = np.linspace(300,550,2)
wl[1] = np.linspace(300,550,2)
wl[2] = np.linspace(300,550,2)
wl[3] = np.linspace(500,1000,2)
wl[4] = np.linspace(500,1000,2)
wl[5] = np.linspace(500,1000,2)
wl[6] = np.linspace(500,1000,2)

temp = sc.loadmat(r'..\data\test_orbit.mat')
test_los = temp['dat']['los'][0,0]
test_mjd = temp['dat']['mjd'][0,0]
test_obs = temp['dat']['obs'][0,0]

num_exposures = 70
exp_offset  = 4678
sat_los = [0,]*num_exposures
sat_pos = [0,]*num_exposures
sat_mjd = [0,]*num_exposures

for i in range(0,num_exposures):
    sat_los[i] = test_los[i,:]
    sat_pos[i] = test_obs[i,:]
    sat_mjd[i] = test_mjd[i]
    
platform = sat.uCATS_platform()
platform.SetSensorLinesOfSight( sat_los, sat_pos )

los  = platform.los
vert = platform.vert
obs  = platform.obs
tp   = platform.tp
inst = ucats.uCATSModel_scan(wl,los, vert, obs)
los_all,obs_all, mjd_all = inst.radtran_geometry()
wavelen = inst.radtran_wavelengths()

atmos = atmosphere.Atmosphere()
atmos.add_species( skif.ISKClimatology('ECMWF'), skif.ISKOpticalProperty('Rayleigh'), skif.SKCLIMATOLOGY_AIRNUMBERDENSITY_CM3 )
atmos.add_species( skif.ISKClimatology('O3LABOW'), skif.ISKOpticalProperty('O3_OSIRISRES'), skif.SKCLIMATOLOGY_O3_CM3 )
atmos.albedo = 0.3

engine = radtran.SasktranGeneric(atmos,'HR')
engine.wavel_nm = wavelen
engine.engine.SetProperty('NumScatterOrder',1)
for i in range (0,np.size(los_all,0)):
    engine.add_line_of_sight(obs_all[i,:],los_all[i,:], sat_mjd[0][0])
    
rad,temp  = engine.calculate_radiance()
meas, meas_los, meas_obs, meas_wavelen = inst.convert_radiance_to_l1(rad)

tp = np.array([])
geodetic = skif.ISKGeodetic()
for i in range(0,np.size(meas_obs,0)):
    geodetic.SetLocationFromTangentPoint(meas_obs[i,:],meas_los[i,:])
    tp = np.append(tp,geodetic.GetAlt())
    
plt.semilogx(meas[num_exposures*3:num_exposures*4,-1],  tp[num_exposures*3:num_exposures*4])
plt.semilogx(meas[num_exposures*4:num_exposures*5,-1],  tp[num_exposures*4:num_exposures*5])
plt.semilogx(meas[num_exposures*5:num_exposures*6,-1],  tp[num_exposures*5:num_exposures*6])
plt.semilogx(meas[num_exposures*6:num_exposures*7,-1],  tp[num_exposures*6:num_exposures*7])

#plt.plot(meas[0:50,0],np.flipud(tp[0:50]))
#plt.plot(meas[50:100,0],np.flipud(tp[50:100]))
#plt.plot(meas[100:150,0],np.flipud(tp[100:150]))