# -*- coding: utf-8 -*-
"""
Created on Fri Jul 17 15:25:48 2015

@author: lar555
"""
import sys
import os
import logging
import yaml
import io
import time
import numpy as np
import h5py
from utility.timing import Timer
from omps.omps_1d_retrieval import OMPSRetrieval
from omps.save_retrieval_output import RetrievalOutputUSASK
import omps.level2 as omps_l2
import omps.omps_processing.omps_jobs_database as omps_sql

def omps_retrieval(yaml_file):
    time.sleep(np.random.rand(1)[0])
    #load in the retrival settings
    with open(yaml_file) as f:
        settings = yaml.load(f)

    #setup logging format
    logger    = logging.getLogger()
    logger.setLevel(logging.INFO)
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

    finished  = False
    jobs      = omps_sql.OMPS_jobs_orbit(settings['database settings']['database_name'],
                                   settings['database settings']['table_name'],
                                   settings['database settings']['database_folder'])
    #get the first job to process
    orbit, slit = jobs.get_next_entry()
    jobs.set_entry_as_processing(orbit, slit)


    while not finished:

        time.sleep(np.random.rand(10)[0])  #avoid all processing starting simultaneously

        #setup/change log file
        # log_capture_string = io.StringIO()
        # fileh = logging.StreamHandler(log_capture_string)   #save to sting for later saving
        # fileh.setFormatter(formatter)
        # logger = logging.getLogger()
        #
        # #get rid of the old logger handlers and add the new one
        # for hdlr in logger.handlers:
        #     logger.removeHandler(hdlr)
        # logger.addHandler(fileh)

        #get solar zenith angle
        try:
            sza = omps_l2.get_orbit_solar_zenith_angle(orbit, slit, settings['retrieval settings']['omps_l1_folder'])
            lat,lon = omps_l2.get_orbit_geolocation_data(orbit, slit, settings['retrieval settings']['omps_anc_folder'] )
        except:
            logging.error('cannot load radiance file')
            sza = 999

        exists = os.path.isfile( settings['output settings']['output_folder'] + 'OMPS_L2_' + str(orbit) + '.h5')
        not_processed = np.ones(sza.shape,dtype=bool)
        if exists:
            try:
                f = h5py.File( settings['output settings']['output_folder'] + 'OMPS_L2_' + str(orbit) + '.h5' )
                temp = f['/Geo/Latitude'][:, slit]
                not_processed = np.isnan(temp)
            except:
                pass

        for image in range(len(sza)):
            try:
                if (sza[image] < 88) & not_processed[image]:  #only process unprocessed scans
                    omps = OMPSRetrieval( orbit, image, slit )

                    for key in settings['retrieval settings']:
                        omps.ret_opt[key]  = settings['retrieval settings'][key]

                    output = omps.retrieve_profiles()

                    h5out = RetrievalOutputUSASK(output)
                    h5out.folder = settings['output settings']['output_folder']
                    h5out.save_to_output_file()
            except:
                logging.error('Scan ' + str(image) + 'failed to process')

        jobs.set_entry_as_finished(orbit, slit)
        orbit, slit = jobs.get_next_entry()
        if orbit is None:
            finished = True
        else:
            jobs.set_entry_as_processing(orbit, slit)

if __name__ == "__main__":
    # print(sys.argv[1])
    omps_retrieval(sys.argv[1])
    # omps_retrieval('yaml_test.yaml')