import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap
from matplotlib.colors    import LinearSegmentedColormap
import matplotlib.axes as max
import numpy as np
import utility.mpl as ras


def plot_worldmap(lat, lon, data, projection='mill',llcrnrlat=-85,urcrnrlat=85, llcrnrlon=-180,urcrnrlon=180,resolution='c',fix_aspect=False, lon_0=0,lat_0=-90, cmap=None, levels=None, labels=True, alpha=0.8, meridian_width=0.0):

    if cmap is None:
        cmap = custom_color_map()
        cmap.set_bad(color='w')

    if projection == 'mill':
        m = Basemap(projection=projection, llcrnrlat=llcrnrlat,urcrnrlat=urcrnrlat, llcrnrlon=llcrnrlon,urcrnrlon=urcrnrlon,resolution=resolution,fix_aspect=fix_aspect)
    elif projection == 'ortho':
        m = Basemap(projection=projection, lon_0=lon_0,lat_0=lat_0,resolution=resolution)

    # lat_grid,lon_grid = np.meshgrid(self.data.lon_smooth, self.data.lat_smooth)
    if len(lat.shape) == 1:
        lon_grid,lat_grid = np.meshgrid(lon, lat)
    else:
        lat_grid = lat
        lon_grid = lon

    x,y = m(lon_grid, lat_grid)

    if labels:
        m.drawparallels(np.arange(-90,91,30),  labels=[True,False,False,False],color=[0.4,0.4,0.4],linewidth=meridian_width,zorder=1)
        m.drawmeridians(np.arange(-180,180,60),labels=[False,False,False,True],color=[0.4,0.4,0.4],linewidth=meridian_width,zorder=1)
    else:
        m.drawparallels(np.arange(-90,91,30),  labels=[False,False,False,False],color=[0.4,0.4,0.4],linewidth=meridian_width,zorder=1)
        m.drawmeridians(np.arange(-180,180,60),labels=[False,False,False,False],color=[0.4,0.4,0.4],linewidth=meridian_width,zorder=1)

    if levels is None:
        c = m.contourf(x,y,np.ma.masked_invalid(data),50,cmap=cmap,alpha=alpha, zorder=4)
    else:
        c = m.contourf(x,y,np.ma.masked_invalid(data),levels=levels,cmap=cmap,alpha=alpha, zorder=4,extend='both', linecolor='none',antialiased=True)

    m.fillcontinents(color=[0.5, 0.5, 0.5],zorder=2)
    # m.drawmapboundary(fill_color=[0.5, 0.5, 0.5],zorder=2)
    # m.fillcontinents(color=[1, 1, 1],lake_color=[0.5, 0.5, 0.5],zorder=2)
    m.drawmapboundary()

    return c

def plot_zonal_ave(lat, alt, data,trop=None, flevels=100, clevels=None, cmap=None):

    if cmap is None:
        cmap = custom_color_map()
        cmap.set_bad(color='w')

    plt.contourf(lat, alt, np.ma.masked_invalid(data), flevels, cmap=cmap, extend='both')
    if clevels is not None:
        plt.contour(lat, alt, np.ma.masked_invalid(data), clevels)

    if trop is not None:
        plt.fill_between(lat, trop, np.zeros(len(lat)),facecolor='w')

    # plt.xlabel('Latitude')
    # plt.ylabel('Altitude [km]')
    plt.ylim(5,50)

def custom_color_map():
    c  = np.array([[60,60,143],
    [0,179,218],
    [171,217,147],
    [215,168,63],
    [150,0,0]])/255

    vmax = 4.0
    cmap = LinearSegmentedColormap.from_list('mycmap', [(0 / vmax, c[0]), (0.75 / vmax, c[1]),(2 / vmax, c[2]),(3 / vmax, c[3]),(4 / vmax, c[4])])
    return cmap