import sqlite3
import numpy as np
import re
import h5py
import os
from astropy.time import Time
from datetime import datetime


class SQLOrbitDatabase:
    def __init__(self, database = 'orbit_info.db', table = 'header', db_folder = '\\\\UTLS\\Users\\data\\OMPS\\'):

        self.anc_folder = '\\\\UTLS\\Users\\data\\OMPS\\OMPS_ANC\\'
        self.database = db_folder + database
        self.table    = table
        self.timeout  = 60

    def make_new_table(self):

        conn = sqlite3.connect(self.database)
        c = conn.cursor()

        c.execute("CREATE TABLE " + str(self.table) + " (orbit PRIMARY KEY, start_mjd, end_mjd)")

        conn.commit()
        conn.close()

    def update_table(self):

        files = os.listdir(self.anc_folder)
        conn = sqlite3.connect(self.database)
        c = conn.cursor()

        for f in files[2::]:
            try:
                m = h5py.File( self.anc_folder + f)
                date = m['/GEOLOCATION_DATA/Date'][0,0]
                time = m['/GEOLOCATION_DATA/Time'][0,0]

                year = np.floor(date/10000);
                month = np.floor( (date-year*10000)/100)
                day = date- year*10000 - month*100

                hour = np.floor(time/60/60)
                minute  = np.floor( (time - hour*60*60)/60)
                sec  = time - hour*60*60 - minute*60

                t = Time(datetime(int(year), int(month), int(day), int(hour), int(minute), int(sec)), scale='utc')
                start_mjd = t.mjd

                date = m['/GEOLOCATION_DATA/Date'][-1,0]
                time = m['/GEOLOCATION_DATA/Time'][-1,0]

                year = np.floor(date/10000);
                month = np.floor( (date-year*10000)/100)
                day = date- year*10000 - month*100

                hour = np.floor(time/60/60)
                minute  = np.floor( (time - hour*60*60)/60)
                sec  = time - hour*60*60 - minute*60

                t = Time(datetime(int(year), int(month), int(day), int(hour), int(minute), int(sec)), scale='utc')
                end_mjd = t.mjd

                m = re.search( 'o([0-9]*)', f )
                orbit = int(m.group(1))

                job = (orbit, start_mjd, end_mjd)
                c.execute('INSERT OR IGNORE INTO ' + self.table + ' VALUES (?,?,?)',job)
            except:
                print(f)

        conn.commit()
        conn.close()
            # except:
            #     pass


    def view_table(self):
        conn = sqlite3.connect(self.database)
        c = conn.cursor()
        #print the last 100 to be processed
        for row in c.execute('SELECT * FROM ' + self.table):
            print(row)


if __name__ == "__main__":

    db = SQLOrbitDatabase()
    try:
        db.make_new_table()
    except:
        pass

    db.update_table()
    db.view_table()