# -*- coding: utf-8 -*-
"""
Created on Fri Jul 17 15:25:48 2015

@author: lar555
"""

import logging

from omps.omps_1d_retrieval import OMPSRetrieval
import matplotlib.pyplot as plt
import utility.plot_results as pr
import omps.level2 as omps_l2
import yaml
import io
import numpy as np
from omps.save_retrieval_output import RetrievalOutputUSASK
from utility.timing import Timer

def omps_retrieval(yaml_file):

    #setup logging format
    logger = logging.getLogger()
    logger.setLevel(logging.INFO)
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

    slits_to_process  = [1] #[1],[0,1], etc
    orbits_to_process = [19043] #can be a list of orbits

    images = [40]

    with open(yaml_file) as f:
        settings = yaml.load(f)

    for orbit in orbits_to_process:
        #setup/change logger
        log_capture_string = io.StringIO()
        fileh = logging.StreamHandler(log_capture_string)   #save to sting for later saving
        # fileh     = logging.FileHandler( log_file + str(orbit) + '.log' )
        fileh.setFormatter(formatter)
        logger = logging.getLogger()

        #get rid of the old logger handlers and add the new one
        for hdlr in logger.handlers:
            logger.removeHandler(hdlr)

        logger.addHandler(fileh)

        for im_idx in images:

            for slit in slits_to_process:

                #get solar zenith angle
                sza = omps_l2.get_image_solar_zenith_angle(orbit, im_idx, slit,settings['retrieval settings']['omps_l1_folder'])

                #only process sunlit scans
                if sza < 88:

                    omps = OMPSRetrieval( orbit, im_idx, slit )
                    for key in settings['retrieval settings']:
                        omps.ret_opt[key]  = settings['retrieval settings'][key]

                    with Timer():
                        output = omps.retrieve_profiles()

                    h5out = RetrievalOutputUSASK(output)
                    # h5out.folder = r'//UTLS/Users/scratch/OMPS_L2_Testing/OMPS_L2/'
                    h5out.folder = r'C:/Users/lar555/Documents/'
                    h5out.filename = 'test.h5'
                    # h5out.save_to_output_file()

                    if omps.ret_opt['verbose_output'] == 2:
                        h5out.plot_output('aerosol')
                        h5out.plot_output('ozone')
                        plt.show()

                else:
                    logger.info('Scan not processed, solar zenith angle too large: ' + str(sza))

if __name__ == "__main__":
    # print(sys.argv[1])
    # omps_retrieval(sys.argv[1])
    omps_retrieval('C:\\Users\\lar555\\Documents\\Software\\Repos_skpython\\omps\\omps_processing\\yaml_test.yaml')