import sasktranif.sasktranif as skif
import numpy as np
import pickle
import scipy.interpolate as interp

def from_text_file( fname ):
    clim = skif.ISKClimatology('USERDEFINED_PROFILE')
    guid_water = guid() 
    optprop = optical_property()
    
    water = np.loadtxt(fname)
    
    clim.SetProperty('Heights', water[:,0] )
    clim.SetProperty('DoLogInterpolation', 1)
    clim.SetProperty('DoPiecewiseLinear', 1)
    clim.SetPropertyUserDefined( guid_water, water[:,1] )
    
    return clim, optprop, guid_water

def guid():
    return skif.SKCLIMATOLOGY_H2O_CM3

def optical_property(wavenumber_range = [1e7/1400.0, 1e7/1300.0]):
    optprop = skif.ISKOpticalProperty('HITRANCHEMICAL_H2O')
    optprop.SetProperty('SetWavenumberRange', wavenumber_range )
    
    return optprop
    
def two_dim_latitude(longitude, user_lats = None):
    """
    
    """
    guid_water = guid()
    optprop = optical_property()
    
    clim = skif.ISKClimatology('USERDEFINED_PROFILE3D_LATLONHEIGHT')
    
    w = pickle.load( open(r'\\utls\\users\\djz828\\show\\old\\data\\water_profiles\\water.p',"rb") )

    if user_lats is None:
        lat = w['lat']
        numden = w['numden']
    else:
        lat = user_lats
        numden = interp.interp1d( w['lat'], w['numden'], axis=0 ) (lat)
        
    lon = w['lon']    
    alts = w['alt']    
    
    prof = np.zeros( (len(lat),2,len(alts)) )    
    
    prof[:,0,:] = interp.interp1d( lon, numden,axis=1 ) (longitude)
    prof[:,1,:] = prof[:,0,:]
    
    clim.SetProperty('Heights', alts)
    clim.SetProperty('Longitudes', [0,360])
    clim.SetProperty('Latitudes', lat )
    clim.SetPropertyUserDefined( guid_water, prof.flatten() )
    
    
    return clim, optprop, guid_water


def three_dim():
    guid_water = guid()
    optprop = optical_property()

    clim = skif.ISKClimatology('USERDEFINED_PROFILE3D_LATLONHEIGHT')
    w = pickle.load(open(r'\\utls\\users\\djz828\\show\\old\\data\\water_profiles\\water.p', "rb"))
    lat = w['lat']
    lon = w['lon']
    numden = w['numden']
    alts = w['alt']

    prof = np.zeros((len(lat), len(lon)+1, len(alts)))
    prof[:, 0:-1, :] = numden
    lon = np.concatenate((lon, [360]))
    prof[:, -1, :] = prof[:, 0, :]

    clim.SetProperty('Heights', alts)
    clim.SetProperty('Longitudes', lon)
    clim.SetProperty('Latitudes', lat)
    clim.SetPropertyUserDefined(guid_water, prof.flatten())

    return clim, optprop, guid_water
