import numpy as np
from typing import Sequence,Tuple
from radtran.datatypes import GEOCENTRIC_XYZ, GEODETIC_COORDS

import sasktranif.sasktranif as skif

#------------------------------------------------------------------------------
#           tangent_points
#------------------------------------------------------------------------------

def tangent_points( observer : Sequence[GEOCENTRIC_XYZ],
                    los      : Sequence[GEOCENTRIC_XYZ]
                    ) -> Tuple[ Sequence[GEODETIC_COORDS], Sequence[float] ]:
    geodetic = skif.ISKGeodetic()
        
    tp = []
    tanalts = []
    for obs, look in zip( observer, los ):
        geodetic.SetLocationFromTangentPoint(obs, look)
        tp.append(geodetic.GetLocationXYZ())
        tanalts.append(geodetic.GetAlt())
            
    return tp, tanalts

#------------------------------------------------------------------------------
#           lat_lon_alts
#------------------------------------------------------------------------------

def lat_lon_alts( loc : Sequence[GEOCENTRIC_XYZ]
                ) -> Tuple[ Sequence[float], Sequence[float], Sequence[float]]:
    geo = skif.ISKGeodetic()
    lat = []
    lon = []
    alt = []    
    for l in loc:
        geo.SetLocationXYZ(l)
        lat.append(geo.GetLatitude())
        lon.append(geo.GetLongitude())
        alt.append(geo.GetAlt())
    
    return np.array(lat), np.array(lon), np.array(alt)