from abc import ABCMeta, abstractmethod

class RadTranWrapper(metaclass=ABCMeta):
    """ Base class which handles radiative transfer calculations in the
        retrieval.
        Radiative transfer models need to be capable of adding lines of sight,
        setting the wavelengths for the calculation, and doing the calculation
    """
    @abstractmethod
    def add_line_of_sight(self, observer, look, mjd):
        raise NotImplementedError()

    @abstractmethod
    def set_wavelengths(self, wavel_nm):
        raise NotImplementedError()

    @abstractmethod
    def calculate_radiance(self):
        raise NotImplementedError()