import retrieval.instruments.instrument as instrument


class IdealSpectrograph(instrument.Instrument):
    # Setting the radiance is optional, if it is not set we will assume this
    # instrument is meant for simulation or retrieval
    def __init__(self, wavel_nm, los, observer, mjd, rad=None):
        self.wavel_nm = wavel_nm
        self.los = los
        self.observer = observer
        self.mjd = mjd
        self.rad = rad
        self.radtran = None
        # Ideal spectrograph does not need any resolution information

    # Called by the retrieval indicating what wavelengths we need to calculate
    # at    
    def set_wavelengths(self, wavel_nm):
        self.wavel_nm = wavel_nm
        if self.radtran is not None:
            self.radtran.set_wavelengths(wavel_nm)

    def setup_radtran_model(self, radtran):
        for observer, look, mjd in zip(self.observer, self.los, self.mjd):
            radtran.add_line_of_sight(observer, look, mjd)

        radtran.set_wavelengths(self.wavel_nm)
        self.radtran = radtran

    # Use the radiative transfer model to calculate the observed radiance
    # for the instrument
    def calculate_radiance(self):
        # Ideal spectrograph just returns back the radiance
        # TODO: Figure out what to do here with weighting functions
        self.rad, self.wf = self.radtran.calculate_radiance()

    def get_meas_geometry(self):
        return self.los, self.observer


