import copy as copy
import logging
import numpy as np

import retrieval.species as species
import retrieval.species_albedo as species_albedo
import radtran.geometry as geo


class SpectralAlbedoLimbProfile(species_albedo.AlbedoLimbProfile):

    def __init__(self, atmosphere, init_albedo=0.3):

        self.ident = 'limb_albedo'

        #TODO: setup triplets from a file albedo is computed as the longest wavelength
        #of the triplet
        self.wavel_nm    = np.arange([400,470,530,600,700,750,800],dtype=np.double)
        self.ref_alt_wavel_nm = 750.0

        self.triplet = []
        for w in self.wavel_nm:
            self.triplet.append( ([w], [1]))

        #TODO: setup normalization based on measurement noise
        self.normalt = [np.array( [25000.0,45000.0])]
        self.ref_idx     = [None] * len(self.triplet)
        self.ref_alt     = np.zeros(len(self.triplet))
        self.good_alts   = None
        self.y_ray       = None
        self.wavel_nm    = None
        self.atmosphere  = atmosphere
        self.refaltrange = 1500.000
        self.max_alt     = 40000
        self.min_alt     = 8000

        self.albedo_wavel = self.triplet[0][0]
        self.albedo = init_albedo

        self.min_step_size = 0.1