import matplotlib as mpl
from matplotlib.collections import Collection
from matplotlib.artist import allow_rasterization


class ListCollection(Collection):
    def __init__(self, collections, **kwargs):
        Collection.__init__(self, **kwargs)
        self.set_collections(collections)

    def set_collections(self, collections):
        self._collections = collections

    def get_collections(self):
        return self._collections

    @allow_rasterization
    def draw(self, renderer):
        for _c in self._collections:
            _c.draw(renderer)


def rasterize_contourf(c, ax=None):
    import matplotlib.pyplot as plt
    collections = c.collections
    for _c in collections:
        _c.remove()
    cc = ListCollection(collections, rasterized=True)
    if ax is None:
        ax = plt.gca()
    ax.add_artist(cc)
    return cc


def pgf():
    mpl.use('pgf')
    pgf_with_rc_fonts = {
        "font.family": "serif",
        "font.serif": [],                   # use latex default serif font
        "font.sans-serif": ["DejaVu Sans"], # use a specific sans-serif font
        "pgf.texsystem": "pdflatex",
    }
    mpl.rcParams.update(pgf_with_rc_fonts)


def latex_axes():
    rc_fonts = {
        "font.family": "sans serif",
        "text.usetex": "True",
        "axes.titleweight": "normal",
    }
    mpl.rcParams.update(rc_fonts)
