import matplotlib.pyplot as plt
import numpy as np

def make_plots( lsq_output, plot_error=True ):

    num_subplots = 2
    if plot_error:
        num_subplots = 3

    apriori_alts = np.arange(0.5,100.5)

    #make some plots
    plt.figure()
    plt.subplot(1,num_subplots,1)
    plt.grid(color=[0.8,0.8,0.8], linestyle='-')
    line1, = plt.plot(lsq_output['apriori'],apriori_alts, color=(0.7,0.4,0.2))
    for i in range(0,len(lsq_output['profile'])):
        line2, = plt.plot(lsq_output['profile'][i],apriori_alts,color=(0.2, 0.4, 0.7,0.5))
    
    line3, = plt.plot(lsq_output['profile'][-1],apriori_alts,color=(0.2, 0.4, 0.7))
    plt.ylim([5, 60])
    plt.ylabel('Altitude [km]')
    plt.xlabel('Number Density')
    num_vec = int(len(lsq_output['y_meas'])/len(lsq_output['tanalts']))
    
    plt.legend([line1,line2,line3],['Apriori','Iterations','Retrieved'])

    plt.subplot(1,num_subplots,2)
    plt.grid(color=[0.8,0.8,0.8], linestyle='-')
    for i in range(num_vec):
        line1, =plt.plot( np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color='black',marker="o" )
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']-lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']+lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)
        
    for i in range(0,len(lsq_output['y_ret'])):
        for j in range(num_vec):
            line2, = plt.plot( np.reshape(lsq_output['y_ret'][i],(num_vec,-1))[j,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7,0.5) )
            
    for i in range(num_vec):
            line3, = plt.plot( np.reshape(lsq_output['y_ret'][-1],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7),linewidth=2 )
            
    plt.ylim([5, 60])
    plt.legend((line1,line2,line3),('Measured','Iterations','Retrieved'))

    if num_vec == 8:
        mylegend = ['292','302','306','310','315','322','331','600']
    elif num_vec == 7:
        mylegend = ['292','302','306','315','322','331','600']
    else:
        mylegend = ['750']

    if plot_error:
        plt.subplot(1,num_subplots,3)
        for i in range(num_vec):
            f = np.reshape(lsq_output['y_ret'][-1],(num_vec,-1))[i,:]
            y = np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:]
            error = (y-f)/y*100
            plt.plot(error, np.asarray(lsq_output['tanalts'])/1000, label=mylegend[i])
            plt.xlabel('Percent Error in Measurement Vectors')
            plt.grid(color=[0.8,0.8,0.8], linestyle='-')

        plt.legend()
        plt.ylim([5, 60])

def make_plots_albedo( lsq_output, plot_error = False ):

    num_subplots = 2
    if plot_error:
        num_subplots = 3

    # make some plots
    plt.figure()
    plt.subplot(1, num_subplots, 1)
    plt.grid(color=[0.8, 0.8, 0.8], linestyle='-')

    line1, = plt.plot(np.arange(0,len(lsq_output['profile']) + 1), np.concatenate(([lsq_output['apriori']], lsq_output['profile'])), marker='o',color=(0.2, 0.4, 0.7),label='Iterations')
    line2 = plt.axhline(lsq_output['profile'][-1],color=(0.2, 0.4, 0.7),linewidth=2,label='Retrieved')
    plt.xlabel('Iteration')
    plt.ylabel('Albedo')
    plt.legend()

    plt.subplot(1, num_subplots, 2)
    plt.grid(color=[0.8, 0.8, 0.8], linestyle='-')
    plt.axhline(lsq_output['y_meas'],color='k',label='Measured')
    plt.plot(np.arange(1,len(lsq_output['y_ret'])+1),lsq_output['y_ret'], color=(0.2, 0.4, 0.7),marker='o',label='Retrieved')
    plt.xlabel('Iteration')
    plt.ylabel('Radiance')
    plt.legend()

    y_min = lsq_output['y_meas'][0] - lsq_output['y_meas_error']
    y_max =lsq_output['y_meas'][0] + lsq_output['y_meas_error']
    plt.fill_between([1,len(lsq_output['y_ret'])+1],[y_min, y_min],[y_max, y_max], color=(0.2, 0.4, 0.7), alpha=0.3)

    if plot_error:
        plt.subplot(1, num_subplots, 3)
        # for i in range(num_vec):
        f = np.asarray(lsq_output['y_ret'])
        y = lsq_output['y_meas']
        error = (y - f) / y * 100
        plt.semilogy(np.arange(1,len(lsq_output['y_ret'])+1,dtype=int), error, color=(0.2, 0.4, 0.7),marker='o')
        plt.ylabel('Percent Error in Measurement Vectors')
        plt.xlabel('Iteration')
        plt.grid(color=[0.8, 0.8, 0.8], linestyle='-')

        # plt.legend()


def make_plots_no2( lsq_output, plot_error=False ):

    num_subplots = 2
    if plot_error:
        num_subplots = 3

    apriori_alts = np.arange(0.5,100.5)

    #make some plots
    plt.figure()
    plt.subplot(1,num_subplots,1)
    plt.grid(color=[0.8,0.8,0.8], linestyle='-')
    line1, = plt.plot(lsq_output['apriori'],apriori_alts, color=(0.7,0.4,0.2))
    for i in range(0,len(lsq_output['profile'])):
        line2, = plt.plot(lsq_output['profile'][i],apriori_alts,color=(0.2, 0.4, 0.7,0.5))

    line3, = plt.plot(lsq_output['profile'][-1],apriori_alts,color=(0.2, 0.4, 0.7))
    plt.ylim([5, 60])
    plt.ylabel('Altitude [km]')
    plt.xlabel('Number Density')
    num_vec = int(len(lsq_output['y_meas'])/len(lsq_output['tanalts']))

    plt.legend([line1,line2,line3],['Apriori','Iterations','Retrieved'])

    plt.subplot(1,num_subplots,2)
    plt.grid(color=[0.8,0.8,0.8], linestyle='-')
    for i in range(num_vec):
        line1, =plt.plot( np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color='black',marker="o" )
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']-lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']+lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)

    for i in range(0,len(lsq_output['y_ret'])):
        for j in range(num_vec):
            line2, = plt.plot( np.reshape(lsq_output['y_ret'][i],(num_vec,-1))[j,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7,0.5) )

    for i in range(num_vec):
            line3, = plt.plot( np.reshape(lsq_output['y_ret'][-1],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7),linewidth=2 )

    plt.ylim([5, 60])
    plt.legend((line1,line2,line3),('Measured','Iterations','Retrieved'))

    if num_vec == 8:
        mylegend = ['292','302','306','310','315','322','331','600']
    elif num_vec == 7:
        mylegend = ['292','302','306','315','322','331','600']
    else:
        mylegend = ['750']

    if plot_error:
        plt.subplot(1,num_subplots,3)
        for i in range(num_vec):
            f = np.reshape(lsq_output['y_ret'][-1],(num_vec,-1))[i,:]
            y = np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:]
            error = (y-f)/y*100
            plt.plot(error, np.asarray(lsq_output['tanalts'])/1000, label=mylegend[i])
            plt.xlabel('Percent Error in Measurement Vectors')
            plt.grid(color=[0.8,0.8,0.8], linestyle='-')

        plt.legend()
        plt.ylim([5, 60])


def make_plots_ps( lsq_output ):
    
    apriori_alts = np.arange(0.5,100.5)

    #make some plots
    plt.figure()
    plt.subplot(1,3,1)
    plt.plot(lsq_output['apriori'][0:100],apriori_alts, color=(0.7,0.4,0.2))
    for i in range(0,len(lsq_output['profile'])):
        plt.plot(lsq_output['profile'][i][0:100],apriori_alts,color=(0.2, 0.4, 0.7,0.5))
    
    plt.plot(lsq_output['profile'][-1][0:100],apriori_alts,color=(0.2, 0.4, 0.7))
    plt.ylim([5, 60])

    
    plt.subplot(1,3,2)
    plt.plot(lsq_output['apriori'][100:200],apriori_alts, color=(0.7,0.4,0.2))
    for i in range(0,len(lsq_output['profile'])):
        plt.plot(lsq_output['profile'][i][100:200],apriori_alts,color=(0.2, 0.4, 0.7,0.5))
    
    plt.plot(lsq_output['profile'][-1][100:200],apriori_alts,color=(0.2, 0.4, 0.7))
    plt.ylim([5, 60])


    num_vec = int(len(lsq_output['y_meas'])/len(lsq_output['tanalts']))
    plt.subplot(1,3,3)
    for i in range(num_vec):
        plt.plot( np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color='black',marker="o" )
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']-lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)
        plt.fill_betweenx(np.asarray(lsq_output['tanalts'])/1000,  np.reshape(lsq_output['y_meas']+lsq_output['y_meas_error'],(num_vec,-1))[i,:],  np.reshape(lsq_output['y_meas'],(num_vec,-1))[i,:], color='black', alpha=0.1)
        
    for i in range(0,len(lsq_output['y_ret'])):
        for j in range(num_vec):
            plt.plot( np.reshape(lsq_output['y_ret'][i],(num_vec,-1))[j,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7,0.5) )
            
    for i in range(num_vec):
            plt.plot( np.reshape(lsq_output['y_ret'][-1],(num_vec,-1))[i,:], np.asarray(lsq_output['tanalts'])/1000, color=(0.2, 0.4, 0.7),linewidth=2 )
            
    plt.ylim([5, 60])