import time

class Timer(object):
    """
    Simple wrapper to time things easier.
    
    Examples
    --------
    The code below runs f()
    
    >>> from utility.timing import Timer
    >>> with Timer():
    >>>     f()
    
    and outputs the elapsed time.  Equivalent in matlab to
    tic; f(); toc;
    """    
    def __init__(self, name=None):
        self.name = name

    def __enter__(self):
        self.tstart = time.time()

    def __exit__(self, type, value, traceback):
        if self.name:
            print(self.name)
        print('Elapsed: ', (time.time() - self.tstart),'s' )